{% extends 'base.html' %}
{% load staticfiles %}

{% block body_class %}forgotpassword{% endblock %}

{% block title %}Forgot Password{% endblock %}

{% block uncached_content %}

  <h1>Forgot Password</h1>
  <section class="form-main-wrapper password-form-container">
    <form action="{% url 'forgot_password' %}" method="post" class="form-generic">
      {{ form.as_p }}
      <input type="submit" value="Reset Password" class="btn btn-primary btn-lg">
    </form>
  </section>

{% endblock %}
